from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voip:
	"""Voip commands group definition. 7 total commands, 0 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("voip", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:ENABle \n
		Snippet: value: bool = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_enable() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:ENABle \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.set_enable(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:ENABle {param}')

	def get_threshold(self) -> float:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:THReshold \n
		Snippet: value: float = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_threshold() \n
		Defines the trigger threshold for the VoIP input path. \n
			:return: threshold: Audio level threshold Range: -100 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:THReshold \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.set_threshold(threshold = 1.0) \n
		Defines the trigger threshold for the VoIP input path. \n
			:param threshold: Audio level threshold Range: -100 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:THReshold {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.TriggerMode:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:MODE \n
		Snippet: value: enums.TriggerMode = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_mode() \n
		Selects the repetition mode of the trigger system. \n
			:return: trigger_mode: SINGle | NORMal | AUTO | FRUN
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerMode)

	def set_mode(self, trigger_mode: enums.TriggerMode) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:MODE \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.set_mode(trigger_mode = enums.TriggerMode.AUTO) \n
		Selects the repetition mode of the trigger system. \n
			:param trigger_mode: SINGle | NORMal | AUTO | FRUN
		"""
		param = Conversions.enum_scalar_to_str(trigger_mode, enums.TriggerMode)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:MODE {param}')

	# noinspection PyTypeChecker
	def get_slope(self) -> enums.SignalSlope:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:SLOPe \n
		Snippet: value: enums.SignalSlope = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_slope() \n
		Selects whether the trigger event is generated by signals rising through the threshold or falling through the threshold. \n
			:return: trigger_slope: REDGe | FEDGe REDGe Rising signal (rising edge) FEDGe Falling signal (falling edge)
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SignalSlope)

	def set_slope(self, trigger_slope: enums.SignalSlope) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:SLOPe \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.set_slope(trigger_slope = enums.SignalSlope.FEDGe) \n
		Selects whether the trigger event is generated by signals rising through the threshold or falling through the threshold. \n
			:param trigger_slope: REDGe | FEDGe REDGe Rising signal (rising edge) FEDGe Falling signal (falling edge)
		"""
		param = Conversions.enum_scalar_to_str(trigger_slope, enums.SignalSlope)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:SLOPe {param}')

	def get_offset(self) -> float:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:OFFSet \n
		Snippet: value: float = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_offset() \n
		Defines a trigger offset, shifting the measured trace relative to the trigger event, so that the trace starts earlier.
		The offset is specified as a percentage of the measurement time for a single trace. \n
			:return: trigger_offset: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, trigger_offset: float) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:OFFSet \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.set_offset(trigger_offset = 1.0) \n
		Defines a trigger offset, shifting the measured trace relative to the trigger event, so that the trace starts earlier.
		The offset is specified as a percentage of the measurement time for a single trace. \n
			:param trigger_offset: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(trigger_offset)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:OFFSet {param}')

	# noinspection PyTypeChecker
	def get_state(self) -> enums.ArmedState:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:STATe \n
		Snippet: value: enums.ArmedState = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_state() \n
		Queries the state of the trigger system. \n
			:return: armed_state: OFF | ARMed | TRIGgered OFF The trigger system is disabled. The oscilloscope works as free-run measurement. ARMed The trigger system is armed and waits for a trigger event. TRIGgered A trigger event has occurred. The trigger system has not (yet) been rearmed.
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.ArmedState)

	# noinspection PyTypeChecker
	def get_coupling(self) -> enums.TriggerCouplingDigital:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:COUPling \n
		Snippet: value: enums.TriggerCouplingDigital = driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.get_coupling() \n
		Couples the trigger settings for the VoIP input path to the trigger settings for another path. \n
			:return: trigger_coupling: NONE | DEMod | AIN No coupling, coupling to RF path or to AF path
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:COUPling?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerCouplingDigital)

	def set_coupling(self, trigger_coupling: enums.TriggerCouplingDigital) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:COUPling \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.voip.set_coupling(trigger_coupling = enums.TriggerCouplingDigital.AIN) \n
		Couples the trigger settings for the VoIP input path to the trigger settings for another path. \n
			:param trigger_coupling: NONE | DEMod | AIN No coupling, coupling to RF path or to AF path
		"""
		param = Conversions.enum_scalar_to_str(trigger_coupling, enums.TriggerCouplingDigital)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:VOIP:COUPling {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RifBandwidth:
	"""RifBandwidth commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rifBandwidth", core, parent)

	def get_sd_method(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SDMethod \n
		Snippet: value: bool = driver.configure.afRf.measurement.searchRoutines.rifBandwidth.get_sd_method() \n
		If enabled, the search routine follows the TIA-603-D specification determining the signal displacement bandwidth and
		starting from the RX sensitivity level. If disabled, the search routine uses a noise level method determining the
		bandwidth, not relying on the RX sensitivity. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SDMethod?')
		return Conversions.str_to_bool(response)

	def set_sd_method(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SDMethod \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rifBandwidth.set_sd_method(enable = False) \n
		If enabled, the search routine follows the TIA-603-D specification determining the signal displacement bandwidth and
		starting from the RX sensitivity level. If disabled, the search routine uses a noise level method determining the
		bandwidth, not relying on the RX sensitivity. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:SDMethod {param}')

	def get_rs_results(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:RSResults \n
		Snippet: value: bool = driver.configure.afRf.measurement.searchRoutines.rifBandwidth.get_rs_results() \n
		If enabled, the result of a previoulsy run RX sensitivity search routine is used. If disabled, the RX sensitivity is
		determined at the first phase of the search routine. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:RSResults?')
		return Conversions.str_to_bool(response)

	def set_rs_results(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:RSResults \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rifBandwidth.set_rs_results(enable = False) \n
		If enabled, the result of a previoulsy run RX sensitivity search routine is used. If disabled, the RX sensitivity is
		determined at the first phase of the search routine. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RIFBandwidth:RSResults {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CmaSound:
	"""CmaSound commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cmaSound", core, parent)

	def get_volume(self) -> int or bool:
		"""SCPI: CONFigure:BASE:CMASound:VOLume \n
		Snippet: value: int or bool = driver.configure.base.cmaSound.get_volume() \n
		Configures the volume of the monitored CMA sound. \n
			:return: cma_sound: OFF Switches off the CMA sound without changing the volume setting ON Switches on the CMA sound without changing the volume setting number A number greater than zero sets the volume and switches on the CMA sound. Zero sets the volume and switches off the CMA sound. Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('CONFigure:BASE:CMASound:VOLume?')
		return Conversions.str_to_int_or_bool(response)

	def set_volume(self, cma_sound: int or bool) -> None:
		"""SCPI: CONFigure:BASE:CMASound:VOLume \n
		Snippet: driver.configure.base.cmaSound.set_volume(cma_sound = 1) \n
		Configures the volume of the monitored CMA sound. \n
			:param cma_sound: OFF Switches off the CMA sound without changing the volume setting ON Switches on the CMA sound without changing the volume setting number A number greater than zero sets the volume and switches on the CMA sound. Zero sets the volume and switches off the CMA sound. Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_or_bool_value_to_str(cma_sound)
		self._core.io.write(f'CONFigure:BASE:CMASound:VOLume {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.SoundSource:
		"""SCPI: CONFigure:BASE:CMASound:SOURce \n
		Snippet: value: enums.SoundSource = driver.configure.base.cmaSound.get_source() \n
		Selects the audio source to be connected to the loudspeaker / headphones. \n
			:return: sound_source: GENone | GENThree | AFONe | SPDif | DEModulator | LAN GENone Generator 1 + generator 2 GENThree Generator 3 + generator 4 AFONe AF1 IN + AF2 IN SPDif SPDIF IN L + R DEModulator Demodulator output LAN LAN connector (voice over IP)
		"""
		response = self._core.io.query_str('CONFigure:BASE:CMASound:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.SoundSource)

	def set_source(self, sound_source: enums.SoundSource) -> None:
		"""SCPI: CONFigure:BASE:CMASound:SOURce \n
		Snippet: driver.configure.base.cmaSound.set_source(sound_source = enums.SoundSource.AFONe) \n
		Selects the audio source to be connected to the loudspeaker / headphones. \n
			:param sound_source: GENone | GENThree | AFONe | SPDif | DEModulator | LAN GENone Generator 1 + generator 2 GENThree Generator 3 + generator 4 AFONe AF1 IN + AF2 IN SPDif SPDIF IN L + R DEModulator Demodulator output LAN LAN connector (voice over IP)
		"""
		param = Conversions.enum_scalar_to_str(sound_source, enums.SoundSource)
		self._core.io.write(f'CONFigure:BASE:CMASound:SOURce {param}')

	def get_squelch(self) -> bool:
		"""SCPI: CONFigure:BASE:CMASound:SQUelch \n
		Snippet: value: bool = driver.configure.base.cmaSound.get_squelch() \n
		Enables or disables the squelch function for the demodulator output to the loudspeaker / headphones. \n
			:return: enable: ON | OFF
		"""
		response = self._core.io.query_str('CONFigure:BASE:CMASound:SQUelch?')
		return Conversions.str_to_bool(response)

	def set_squelch(self, enable: bool) -> None:
		"""SCPI: CONFigure:BASE:CMASound:SQUelch \n
		Snippet: driver.configure.base.cmaSound.set_squelch(enable = False) \n
		Enables or disables the squelch function for the demodulator output to the loudspeaker / headphones. \n
			:param enable: ON | OFF
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:BASE:CMASound:SQUelch {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.Utilities import trim_str_response
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentDirectory:
	"""CurrentDirectory commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("currentDirectory", core, parent)

	def set(self, directory_name: str = None) -> None:
		"""SCPI: MMEMory:CDIRectory \n
		Snippet: driver.massMemory.currentDirectory.set(directory_name = '1') \n
		Changes the current directory for file access. \n
			:param directory_name: String parameter to specify the directory. If the parameter is omitted, the current directory is set to '/'. If the string contains not only a directory, but also a drive letter or server name, the command MMEMory:MSIS is also executed automatically.
		"""
		param = ''
		if directory_name:
			param = Conversions.value_to_quoted_str(directory_name)
		self._core.io.write(f'MMEMory:CDIRectory {param}'.strip())

	def get(self, directory_name: str = None) -> str:
		"""SCPI: MMEMory:CDIRectory \n
		Snippet: value: str = driver.massMemory.currentDirectory.get(directory_name = '1') \n
		Changes the current directory for file access. \n
			:param directory_name: String parameter to specify the directory. If the parameter is omitted, the current directory is set to '/'. If the string contains not only a directory, but also a drive letter or server name, the command MMEMory:MSIS is also executed automatically.
			:return: directory_name: String parameter to specify the directory. If the parameter is omitted, the current directory is set to '/'. If the string contains not only a directory, but also a drive letter or server name, the command MMEMory:MSIS is also executed automatically."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('directory_name', directory_name, DataType.String, True))
		response = self._core.io.query_str(f'MMEMory:CDIRectory? {param}'.rstrip())
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfCarrier:
	"""RfCarrier commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfCarrier", core, parent)

	# noinspection PyTypeChecker
	class PowerStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Limit: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower power limit Range: -130 dBm to 55 dBm, Unit: dBm
			- Upper: float: Upper power limit Range: -130 dBm to 55 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Limit'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Limit: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_power(self) -> PowerStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:POWer \n
		Snippet: value: PowerStruct = driver.configure.afRf.measurement.multiEval.limit.rfCarrier.get_power() \n
		Configures limits for the measured RF signal power (RMS value) . \n
			:return: structure: for return value, see the help for PowerStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:POWer?', self.__class__.PowerStruct())

	def set_power(self, value: PowerStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:POWer \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.rfCarrier.set_power(value = PowerStruct()) \n
		Configures limits for the measured RF signal power (RMS value) . \n
			:param value: see the help for PowerStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:POWer', value)

	# noinspection PyTypeChecker
	class FreqErrorStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Limit: bool: OFF | ON Enables or disables the limit check
			- Lower: float: A query returns the lower limit. A setting applies the absolute value to the upper limit and the absolute value plus a negative sign to the lower limit. Range: -50 kHz to 0 Hz, Unit: Hz
			- Upper: float: A query returns the upper limit. A setting ignores this parameter. Range: 0 Hz to 50 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Limit'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Limit: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_freq_error(self) -> FreqErrorStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:FERRor \n
		Snippet: value: FreqErrorStruct = driver.configure.afRf.measurement.multiEval.limit.rfCarrier.get_freq_error() \n
		Configures limits for the measured RF carrier frequency error. The upper and lower limits have the same absolute value
		but different signs. \n
			:return: structure: for return value, see the help for FreqErrorStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:FERRor?', self.__class__.FreqErrorStruct())

	def set_freq_error(self, value: FreqErrorStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:FERRor \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.rfCarrier.set_freq_error(value = FreqErrorStruct()) \n
		Configures limits for the measured RF carrier frequency error. The upper and lower limits have the same absolute value
		but different signs. \n
			:param value: see the help for FreqErrorStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:RFCarrier:FERRor', value)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tlevel:
	"""Tlevel commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tlevel", core, parent)

	def set(self, tlevel: List[float], internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:TLEVel \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.tlevel.set(tlevel = [1.1, 2.2, 3.3], internalGen = repcap.InternalGen.Default) \n
		Sets the total level of a multitone signal for edit mode TOTal. In edit mode INDividual, you can only query the total
		level, but not configure it. \n
			:param tlevel: Total level
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.list_to_csv_str(tlevel)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:TLEVel {param}')

	def get(self, internalGen=repcap.InternalGen.Default) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:TLEVel \n
		Snippet: value: List[float] = driver.source.afRf.generator.internalGenerator.multiTone.tlevel.get(internalGen = repcap.InternalGen.Default) \n
		Sets the total level of a multitone signal for edit mode TOTal. In edit mode INDividual, you can only query the total
		level, but not configure it. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: tlevel: Total level"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_bin_or_ascii_float_list(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:TLEVel?')
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set_all(self, enable: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:MARKer:ENABle:ALL \n
		Snippet: driver.configure.gprfMeasurement.spectrum.marker.enable.set_all(enable = False) \n
		Enables or disables all markers for the frequency sweep mode and the zero span mode. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:MARKer:ENABle:ALL {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Attenuation:
	"""Attenuation commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("attenuation", core, parent)

	# noinspection PyTypeChecker
	def get_port(self) -> enums.AttenuationPort:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:PORT \n
		Snippet: value: enums.AttenuationPort = driver.configure.gprfMeasurement.nrt.attenuation.get_port() \n
		Selects the NRT-Z port to be used as measurement point. \n
			:return: attenuation_port: SOURce | LOAD
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:PORT?')
		return Conversions.str_to_scalar_enum(response, enums.AttenuationPort)

	def set_port(self, attenuation_port: enums.AttenuationPort) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:PORT \n
		Snippet: driver.configure.gprfMeasurement.nrt.attenuation.set_port(attenuation_port = enums.AttenuationPort.LOAD) \n
		Selects the NRT-Z port to be used as measurement point. \n
			:param attenuation_port: SOURce | LOAD
		"""
		param = Conversions.enum_scalar_to_str(attenuation_port, enums.AttenuationPort)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:PORT {param}')

	def get_state(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:STATe \n
		Snippet: value: bool = driver.configure.gprfMeasurement.nrt.attenuation.get_state() \n
		Enables or disables the compensation of the external attenuation configured via method RsCma.Configure.GprfMeasurement.
		Nrt.Attenuation.value. \n
			:return: attenuator_state: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, attenuator_state: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:STATe \n
		Snippet: driver.configure.gprfMeasurement.nrt.attenuation.set_state(attenuator_state = False) \n
		Enables or disables the compensation of the external attenuation configured via method RsCma.Configure.GprfMeasurement.
		Nrt.Attenuation.value. \n
			:param attenuator_state: OFF | ON
		"""
		param = Conversions.bool_to_str(attenuator_state)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation:STATe {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation \n
		Snippet: value: float = driver.configure.gprfMeasurement.nrt.attenuation.get_value() \n
		Specifies the attenuation of a component between the power sensor and the DUT, typically a cable. The power readings are
		corrected accordingly, if the correction is enabled via method RsCma.Configure.GprfMeasurement.Nrt.Attenuation.state. \n
			:return: attenuation: Range: 0 dB to 100 dB, Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation?')
		return Conversions.str_to_float(response)

	def set_value(self, attenuation: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation \n
		Snippet: driver.configure.gprfMeasurement.nrt.attenuation.set_value(attenuation = 1.0) \n
		Specifies the attenuation of a component between the power sensor and the DUT, typically a cable. The power readings are
		corrected accordingly, if the correction is enabled via method RsCma.Configure.GprfMeasurement.Nrt.Attenuation.state. \n
			:param attenuation: Range: 0 dB to 100 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:ATTenuation {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModDepth:
	"""ModDepth commands group definition. 2 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("modDepth", core, parent)

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_current'):
			from .ModDepth_.Current import Current
			self._current = Current(self._core, self._base)
		return self._current

	def clone(self) -> 'ModDepth':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ModDepth(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExtPwrSensor:
	"""ExtPwrSensor commands group definition. 9 total commands, 2 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("extPwrSensor", core, parent)

	@property
	def average(self):
		"""average commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_average'):
			from .ExtPwrSensor_.Average import Average
			self._average = Average(self._core, self._base)
		return self._average

	@property
	def attenuation(self):
		"""attenuation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_attenuation'):
			from .ExtPwrSensor_.Attenuation import Attenuation
			self._attenuation = Attenuation(self._core, self._base)
		return self._attenuation

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:TOUT \n
		Snippet: value: float = driver.configure.gprfMeasurement.extPwrSensor.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:TOUT \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: Unit: s
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:TOUT {param}')

	# noinspection PyTypeChecker
	def get_resolution(self) -> enums.ExtSensorResolution:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:RESolution \n
		Snippet: value: enums.ExtSensorResolution = driver.configure.gprfMeasurement.extPwrSensor.get_resolution() \n
		Defines the number of decimal places of the power results displayed in the graphical user interface. This command does
		not affect results queried via remote control commands. \n
			:return: resolution: PD0 | PD1 | PD2 | PD3 PDn Results rounded to n places after the decimal point
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:RESolution?')
		return Conversions.str_to_scalar_enum(response, enums.ExtSensorResolution)

	def set_resolution(self, resolution: enums.ExtSensorResolution) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:RESolution \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.set_resolution(resolution = enums.ExtSensorResolution.PD0) \n
		Defines the number of decimal places of the power results displayed in the graphical user interface. This command does
		not affect results queried via remote control commands. \n
			:param resolution: PD0 | PD1 | PD2 | PD3 PDn Results rounded to n places after the decimal point
		"""
		param = Conversions.enum_scalar_to_str(resolution, enums.ExtSensorResolution)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:RESolution {param}')

	def get_scount(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:SCOunt \n
		Snippet: value: int = driver.configure.gprfMeasurement.extPwrSensor.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval comprises one power result
		requested from the power sensor. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:SCOunt \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval comprises one power result
		requested from the power sensor. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:SCOunt {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.gprfMeasurement.extPwrSensor.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:REPetition \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:REPetition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:RCOupling \n
		Snippet: value: bool = driver.configure.gprfMeasurement.extPwrSensor.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupl: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupl: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:RCOupling \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.set_rcoupling(repetition_coupl = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupl: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupl)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:RCOupling {param}')

	def get_frequency(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:FREQuency \n
		Snippet: value: float = driver.configure.gprfMeasurement.extPwrSensor.get_frequency() \n
		Specifies the input frequency at the power sensor. \n
			:return: correction_freq: Range: Depends on used sensor model , Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, correction_freq: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:FREQuency \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.set_frequency(correction_freq = 1.0) \n
		Specifies the input frequency at the power sensor. \n
			:param correction_freq: Range: Depends on used sensor model , Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(correction_freq)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:FREQuency {param}')

	def clone(self) -> 'ExtPwrSensor':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ExtPwrSensor(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Operation:
	"""Operation commands group definition. 10 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("operation", core, parent)

	@property
	def bit(self):
		"""bit commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_bit'):
			from .Operation_.Bit import Bit
			self._bit = Bit(self._core, self._base)
		return self._bit

	def get_event(self) -> int:
		"""SCPI: STATus:OPERation[:EVENt] \n
		Snippet: value: int = driver.status.operation.get_event() \n
		No command help available \n
			:return: register_value: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:EVENt?')
		return Conversions.str_to_int(response)

	def get_condition(self) -> int:
		"""SCPI: STATus:OPERation:CONDition \n
		Snippet: value: int = driver.status.operation.get_condition() \n
		No command help available \n
			:return: register_value: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:CONDition?')
		return Conversions.str_to_int(response)

	def get_enable(self) -> int:
		"""SCPI: STATus:OPERation:ENABle \n
		Snippet: value: int = driver.status.operation.get_enable() \n
		No command help available \n
			:return: register_value: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:ENABle?')
		return Conversions.str_to_int(response)

	def set_enable(self, register_value: int) -> None:
		"""SCPI: STATus:OPERation:ENABle \n
		Snippet: driver.status.operation.set_enable(register_value = 1) \n
		No command help available \n
			:param register_value: No help available
		"""
		param = Conversions.decimal_value_to_str(register_value)
		self._core.io.write(f'STATus:OPERation:ENABle {param}')

	def get_ptransition(self) -> int:
		"""SCPI: STATus:OPERation:PTRansition \n
		Snippet: value: int = driver.status.operation.get_ptransition() \n
		No command help available \n
			:return: register_value: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:PTRansition?')
		return Conversions.str_to_int(response)

	def set_ptransition(self, register_value: int) -> None:
		"""SCPI: STATus:OPERation:PTRansition \n
		Snippet: driver.status.operation.set_ptransition(register_value = 1) \n
		No command help available \n
			:param register_value: No help available
		"""
		param = Conversions.decimal_value_to_str(register_value)
		self._core.io.write(f'STATus:OPERation:PTRansition {param}')

	def get_ntransition(self) -> int:
		"""SCPI: STATus:OPERation:NTRansition \n
		Snippet: value: int = driver.status.operation.get_ntransition() \n
		No command help available \n
			:return: register_value: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:NTRansition?')
		return Conversions.str_to_int(response)

	def set_ntransition(self, register_value: int) -> None:
		"""SCPI: STATus:OPERation:NTRansition \n
		Snippet: driver.status.operation.set_ntransition(register_value = 1) \n
		No command help available \n
			:param register_value: No help available
		"""
		param = Conversions.decimal_value_to_str(register_value)
		self._core.io.write(f'STATus:OPERation:NTRansition {param}')

	def clone(self) -> 'Operation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Operation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from enum import Enum


# noinspection SpellCheckingInspection
class AcpOffset(Enum):
	"""3 Members, LSB ... USB"""
	LSB = 0
	NONE = 1
	USB = 2


# noinspection SpellCheckingInspection
class Activity(Enum):
	"""2 Members, ACTive ... INACtive"""
	ACTive = 0
	INACtive = 1


# noinspection SpellCheckingInspection
class AnalogDigital(Enum):
	"""2 Members, ANALog ... DIGital"""
	ANALog = 0
	DIGital = 1


# noinspection SpellCheckingInspection
class ArbSamplesRange(Enum):
	"""2 Members, FULL ... SUB"""
	FULL = 0
	SUB = 1


# noinspection SpellCheckingInspection
class ArmedState(Enum):
	"""3 Members, ARMed ... TRIGgered"""
	ARMed = 0
	OFF = 1
	TRIGgered = 2


# noinspection SpellCheckingInspection
class AttenuationPort(Enum):
	"""2 Members, LOAD ... SOURce"""
	LOAD = 0
	SOURce = 1


# noinspection SpellCheckingInspection
class AudioConnector(Enum):
	"""2 Members, AF1O ... AF2O"""
	AF1O = 0
	AF2O = 1


# noinspection SpellCheckingInspection
class AudioSource(Enum):
	"""5 Members, DEM ... UGEN"""
	DEM = 0
	DEML = 1
	DEMR = 2
	NONE = 3
	UGEN = 4


# noinspection SpellCheckingInspection
class AveragingMode(Enum):
	"""2 Members, LINear ... LOGarithmic"""
	LINear = 0
	LOGarithmic = 1


# noinspection SpellCheckingInspection
class BandpassFilter(Enum):
	"""5 Members, F01M ... F8330"""
	F01M = 0
	F05M = 1
	F25K = 2
	F50K = 3
	F8330 = 4


# noinspection SpellCheckingInspection
class BaseScenario(Enum):
	"""12 Members, AUDio ... TXTest"""
	AUDio = 0
	AVIonics = 1
	DEXPert = 2
	DRXTest = 3
	DSPectrum = 4
	DTXTest = 5
	DXTest = 6
	EXPert = 7
	RXTest = 8
	SEQuencer = 9
	SPECtrum = 10
	TXTest = 11


# noinspection SpellCheckingInspection
class BatteryUsage(Enum):
	"""3 Members, NAV ... USED"""
	NAV = 0
	REMovable = 1
	USED = 2


# noinspection SpellCheckingInspection
class ByteOrder(Enum):
	"""2 Members, NORMal ... SWAPped"""
	NORMal = 0
	SWAPped = 1


# noinspection SpellCheckingInspection
class CalibType(Enum):
	"""4 Members, CALibration ... UCORrection"""
	CALibration = 0
	FSCorrection = 1
	OGCal = 2
	UCORrection = 3


# noinspection SpellCheckingInspection
class CatalogFormat(Enum):
	"""2 Members, ALL ... WTIMe"""
	ALL = 0
	WTIMe = 1


# noinspection SpellCheckingInspection
class CircuitryState(Enum):
	"""2 Members, ACTive ... PASSive"""
	ACTive = 0
	PASSive = 1


# noinspection SpellCheckingInspection
class ClockIn(Enum):
	"""2 Members, PIN14 ... PIN15"""
	PIN14 = 0
	PIN15 = 1


# noinspection SpellCheckingInspection
class CrestFactor(Enum):
	"""2 Members, LOW ... MAXimum"""
	LOW = 0
	MAXimum = 1


# noinspection SpellCheckingInspection
class DataFormat(Enum):
	"""8 Members, ASCii ... UINTeger"""
	ASCii = 0
	BINary = 1
	HEXadecimal = 2
	INTeger = 3
	OCTal = 4
	PACKed = 5
	REAL = 6
	UINTeger = 7


# noinspection SpellCheckingInspection
class DefaultUnitAngle(Enum):
	"""3 Members, DEG ... RAD"""
	DEG = 0
	GRAD = 1
	RAD = 2


# noinspection SpellCheckingInspection
class DefaultUnitCapacity(Enum):
	"""13 Members, AF ... UF"""
	AF = 0
	EXF = 1
	F = 2
	FF = 3
	GF = 4
	KF = 5
	MF = 6
	MIF = 7
	NF = 8
	PEF = 9
	PF = 10
	TF = 11
	UF = 12


# noinspection SpellCheckingInspection
class DefaultUnitCharge(Enum):
	"""13 Members, AC ... UC"""
	AC = 0
	C = 1
	EXC = 2
	FC = 3
	GC = 4
	KC = 5
	MC = 6
	MIC = 7
	NC = 8
	PC = 9
	PEC = 10
	TC = 11
	UC = 12


# noinspection SpellCheckingInspection
class DefaultUnitConductance(Enum):
	"""13 Members, ASIE ... USIE"""
	ASIE = 0
	EXSie = 1
	FSIE = 2
	GSIE = 3
	KSIE = 4
	MISie = 5
	MSIE = 6
	NSIE = 7
	PESie = 8
	PSIE = 9
	SIE = 10
	TSIE = 11
	USIE = 12


# noinspection SpellCheckingInspection
class DefaultUnitCurrent(Enum):
	"""18 Members, A ... UA"""
	A = 0
	AA = 1
	DBA = 2
	DBMA = 3
	DBNA = 4
	DBPA = 5
	DBUA = 6
	EXA = 7
	FA = 8
	GA = 9
	KA = 10
	MA = 11
	MAA = 12
	NA = 13
	PA = 14
	PEA = 15
	TA = 16
	UA = 17


# noinspection SpellCheckingInspection
class DefaultUnitEnergy(Enum):
	"""13 Members, AJ ... UJ"""
	AJ = 0
	EXJ = 1
	FJ = 2
	GJ = 3
	J = 4
	KJ = 5
	MIJ = 6
	MJ = 7
	NJ = 8
	PEJ = 9
	PJ = 10
	TJ = 11
	UJ = 12


# noinspection SpellCheckingInspection
class DefaultUnitFrequency(Enum):
	"""13 Members, AHZ ... UHZ"""
	AHZ = 0
	EXHZ = 1
	FHZ = 2
	GHZ = 3
	HZ = 4
	KHZ = 5
	MHZ = 6
	MIHZ = 7
	NHZ = 8
	PEHZ = 9
	PHZ = 10
	THZ = 11
	UHZ = 12


# noinspection SpellCheckingInspection
class DefaultUnitFullScale(Enum):
	"""4 Members, DBFS ... PPM"""
	DBFS = 0
	FS = 1
	PCT = 2
	PPM = 3


# noinspection SpellCheckingInspection
class DefaultUnitLenght(Enum):
	"""13 Members, AM ... UM"""
	AM = 0
	EXM = 1
	FM = 2
	GM = 3
	KM = 4
	M = 5
	MAM = 6
	MM = 7
	NM = 8
	PEM = 9
	PM = 10
	TM = 11
	UM = 12


# noinspection SpellCheckingInspection
class DefaultUnitPower(Enum):
	"""19 Members, AW ... W"""
	AW = 0
	DBM = 1
	DBMW = 2
	DBNW = 3
	DBPW = 4
	DBUW = 5
	DBW = 6
	EXW = 7
	FW = 8
	GW = 9
	KW = 10
	MIW = 11
	MW = 12
	NW = 13
	PEW = 14
	PW = 15
	TW = 16
	UW = 17
	W = 18


# noinspection SpellCheckingInspection
class DefaultUnitResistor(Enum):
	"""13 Members, AOHM ... UOHM"""
	AOHM = 0
	EXOHm = 1
	FOHM = 2
	GOHM = 3
	KOHM = 4
	MIOHm = 5
	MOHM = 6
	NOHM = 7
	OHM = 8
	PEOHm = 9
	POHM = 10
	TOHM = 11
	UOHM = 12


# noinspection SpellCheckingInspection
class DefaultUnitTemperature(Enum):
	"""6 Members, C ... KEL"""
	C = 0
	CEL = 1
	F = 2
	FAR = 3
	K = 4
	KEL = 5


# noinspection SpellCheckingInspection
class DefaultUnitTime(Enum):
	"""18 Members, AS ... US"""
	AS = 0
	EXS = 1
	FS = 2
	GS = 3
	H = 4
	HOUR = 5
	KS = 6
	M = 7
	MAS = 8
	MIN = 9
	MS = 10
	NS = 11
	PES = 12
	PS = 13
	S = 14
	SEC = 15
	TS = 16
	US = 17


# noinspection SpellCheckingInspection
class DefaultUnitVoltage(Enum):
	"""18 Members, AV ... V"""
	AV = 0
	DBMV = 1
	DBNV = 2
	DBPV = 3
	DBUV = 4
	DBV = 5
	EXV = 6
	FV = 7
	GV = 8
	KV = 9
	MAV = 10
	MV = 11
	NV = 12
	PEV = 13
	PV = 14
	TV = 15
	UV = 16
	V = 17


# noinspection SpellCheckingInspection
class DeltaMode(Enum):
	"""3 Members, MEAS ... USER"""
	MEAS = 0
	NONE = 1
	USER = 2


# noinspection SpellCheckingInspection
class Demodulation(Enum):
	"""6 Members, AM ... USB"""
	AM = 0
	FM = 1
	FMSTereo = 2
	LSB = 3
	PM = 4
	USB = 5


# noinspection SpellCheckingInspection
class DemodulationType(Enum):
	"""1 Members, FSK4 ... FSK4"""
	FSK4 = 0


# noinspection SpellCheckingInspection
class Detector(Enum):
	"""6 Members, AUTopeak ... SAMPle"""
	AUTopeak = 0
	AVERage = 1
	MAXPeak = 2
	MINPeak = 3
	RMS = 4
	SAMPle = 5


# noinspection SpellCheckingInspection
class DetectorSimple(Enum):
	"""2 Members, PEAK ... RMS"""
	PEAK = 0
	RMS = 1


# noinspection SpellCheckingInspection
class DialingMode(Enum):
	"""4 Members, DTMF ... SELCall"""
	DTMF = 0
	FDIaling = 1
	SCAL = 2
	SELCall = 3


# noinspection SpellCheckingInspection
class DigitalSource(Enum):
	"""8 Members, ARB ... ZIGBee"""
	ARB = 0
	DMR = 1
	DPMR = 2
	NXDN = 3
	P25 = 4
	POCSag = 5
	UDEFined = 6
	ZIGBee = 7


# noinspection SpellCheckingInspection
class DigitalToneMode(Enum):
	"""6 Members, DCS ... SELCall"""
	DCS = 0
	DTMF = 1
	FDIA = 2
	NONE = 3
	SCAL = 4
	SELCall = 5


# noinspection SpellCheckingInspection
class DirectionIo(Enum):
	"""2 Members, IN ... OUT"""
	IN = 0
	OUT = 1


# noinspection SpellCheckingInspection
class DirPwrSensorFwdValue(Enum):
	"""4 Members, CCDF ... PEP"""
	CCDF = 0
	CFAC = 1
	FPWR = 2
	PEP = 3


# noinspection SpellCheckingInspection
class DirPwrSensorRevValue(Enum):
	"""4 Members, REFL ... SWR"""
	REFL = 0
	RLOS = 1
	RPWR = 2
	SWR = 3


# noinspection SpellCheckingInspection
class DisplayLanguage(Enum):
	"""14 Members, AR ... ZH"""
	AR = 0
	CS = 1
	DA = 2
	DE = 3
	EN = 4
	ES = 5
	FR = 6
	IT = 7
	JA = 8
	KO = 9
	RU = 10
	SV = 11
	TR = 12
	ZH = 13


# noinspection SpellCheckingInspection
class DmrPattern(Enum):
	"""16 Members, BPRB15 ... SILence"""
	BPRB15 = 0
	BPRB9 = 1
	C153 = 2
	O153 = 3
	P1031 = 4
	PRBS9 = 5
	R10A = 6
	RA0 = 7
	RA1 = 8
	RFBS = 9
	RFMS = 10
	RLD = 11
	RPRB15 = 12
	RPRB9 = 13
	RSYR = 14
	SILence = 15


# noinspection SpellCheckingInspection
class Dstrategy(Enum):
	"""2 Members, BYLayout ... OFF"""
	BYLayout = 0
	OFF = 1


# noinspection SpellCheckingInspection
class Eformat(Enum):
	"""2 Members, ASCii ... XML"""
	ASCii = 0
	XML = 1


# noinspection SpellCheckingInspection
class EstartMode(Enum):
	"""2 Members, AUTO ... EXPLicit"""
	AUTO = 0
	EXPLicit = 1


# noinspection SpellCheckingInspection
class EstopMode(Enum):
	"""4 Members, AUTO ... EXPLicit"""
	AUTO = 0
	BUFFerfull = 1
	ERRor = 2
	EXPLicit = 3


# noinspection SpellCheckingInspection
class ExpFrequency(Enum):
	"""2 Members, CONF ... FGEN"""
	CONF = 0
	FGEN = 1


# noinspection SpellCheckingInspection
class ExpressionMode(Enum):
	"""2 Members, REGex ... STRing"""
	REGex = 0
	STRing = 1


# noinspection SpellCheckingInspection
class ExtPwrSensorApp(Enum):
	"""2 Members, EPS ... NRTZ"""
	EPS = 0
	NRTZ = 1


# noinspection SpellCheckingInspection
class ExtSensorResolution(Enum):
	"""4 Members, PD0 ... PD3"""
	PD0 = 0
	PD1 = 1
	PD2 = 2
	PD3 = 3


# noinspection SpellCheckingInspection
class FftLength(Enum):
	"""3 Members, F16K ... F8K"""
	F16K = 0
	F4K = 1
	F8K = 2


# noinspection SpellCheckingInspection
class FftOffsetMode(Enum):
	"""2 Members, FIXed ... VARiable"""
	FIXed = 0
	VARiable = 1


# noinspection SpellCheckingInspection
class FftSpan(Enum):
	"""4 Members, SP1 ... SP5"""
	SP1 = 0
	SP10 = 1
	SP21 = 2
	SP5 = 3


# noinspection SpellCheckingInspection
class FftWindowType(Enum):
	"""5 Members, BLHA ... RECTangle"""
	BLHA = 0
	FLTP = 1
	HAMMing = 2
	HANN = 3
	RECTangle = 4


# noinspection SpellCheckingInspection
class FileSave(Enum):
	"""3 Members, OFF ... ONLY"""
	OFF = 0
	ON = 1
	ONLY = 2


# noinspection SpellCheckingInspection
class FilterNxDn(Enum):
	"""1 Members, NXTX ... NXTX"""
	NXTX = 0


# noinspection SpellCheckingInspection
class FilterType(Enum):
	"""5 Members, BANDpass ... WCDMa"""
	BANDpass = 0
	CDMA = 1
	GAUSs = 2
	TDSCdma = 3
	WCDMa = 4


# noinspection SpellCheckingInspection
class FreqCounterMode(Enum):
	"""2 Members, HW ... SW"""
	HW = 0
	SW = 1


# noinspection SpellCheckingInspection
class FskMode(Enum):
	"""2 Members, FSK2 ... FSK4"""
	FSK2 = 0
	FSK4 = 1


# noinspection SpellCheckingInspection
class GeneratorCoupling(Enum):
	"""5 Members, GEN1 ... OFF"""
	GEN1 = 0
	GEN2 = 1
	GEN3 = 2
	GEN4 = 3
	OFF = 4


# noinspection SpellCheckingInspection
class GeneratorCouplingVoIp(Enum):
	"""3 Members, GEN3 ... OFF"""
	GEN3 = 0
	GEN4 = 1
	OFF = 2


# noinspection SpellCheckingInspection
class GeneratorFilter(Enum):
	"""5 Members, COS ... SINC"""
	COS = 0
	GAUSs = 1
	RC = 2
	RRC = 3
	SINC = 4


# noinspection SpellCheckingInspection
class GeneratorState(Enum):
	"""7 Members, ADJusted ... PENDing"""
	ADJusted = 0
	AUTonomous = 1
	COUPled = 2
	INValid = 3
	OFF = 4
	ON = 5
	PENDing = 6


# noinspection SpellCheckingInspection
class HighpassFilter(Enum):
	"""2 Members, F300 ... OFF"""
	F300 = 0
	OFF = 1


# noinspection SpellCheckingInspection
class HighpassFilterExtended(Enum):
	"""4 Members, F300 ... OFF"""
	F300 = 0
	F50 = 1
	F6 = 2
	OFF = 3


# noinspection SpellCheckingInspection
class IlsLetter(Enum):
	"""2 Members, X ... Y"""
	X = 0
	Y = 1


# noinspection SpellCheckingInspection
class IlsTab(Enum):
	"""2 Members, GSLope ... LOCalizer"""
	GSLope = 0
	LOCalizer = 1


# noinspection SpellCheckingInspection
class Impedance(Enum):
	"""5 Members, IHOL ... R600"""
	IHOL = 0
	R150 = 1
	R300 = 2
	R50 = 3
	R600 = 4


# noinspection SpellCheckingInspection
class ImpulseLength(Enum):
	"""5 Members, T ... T8"""
	T = 0
	T2 = 1
	T4 = 2
	T6 = 3
	T8 = 4


# noinspection SpellCheckingInspection
class InputConnector(Enum):
	"""2 Members, RFCom ... RFIN"""
	RFCom = 0
	RFIN = 1


# noinspection SpellCheckingInspection
class InterfererMode(Enum):
	"""5 Members, AM ... PM"""
	AM = 0
	CW = 1
	FM = 2
	NONE = 3
	PM = 4


# noinspection SpellCheckingInspection
class IqFormat(Enum):
	"""2 Members, IQ ... RPHI"""
	IQ = 0
	RPHI = 1


# noinspection SpellCheckingInspection
class LeftRightDirection(Enum):
	"""2 Members, LEFT ... RIGHt"""
	LEFT = 0
	RIGHt = 1


# noinspection SpellCheckingInspection
class LevelEditMode(Enum):
	"""2 Members, INDividual ... TOTal"""
	INDividual = 0
	TOTal = 1


# noinspection SpellCheckingInspection
class LockRangeExternal(Enum):
	"""4 Members, INV ... WIDE"""
	INV = 0
	MEDium = 1
	NARRow = 2
	WIDE = 3


# noinspection SpellCheckingInspection
class LockRangeInternal(Enum):
	"""3 Members, INV ... NARRow"""
	INV = 0
	MEDium = 1
	NARRow = 2


# noinspection SpellCheckingInspection
class LowHigh(Enum):
	"""2 Members, HIGH ... LOW"""
	HIGH = 0
	LOW = 1


# noinspection SpellCheckingInspection
class LowpassFilter(Enum):
	"""4 Members, F15K ... OFF"""
	F15K = 0
	F3K = 1
	F4K = 2
	OFF = 3


# noinspection SpellCheckingInspection
class LowpassFilterExtended(Enum):
	"""6 Members, F15K ... OFF"""
	F15K = 0
	F255 = 1
	F3K = 2
	F3K4 = 3
	F4K = 4
	OFF = 5


# noinspection SpellCheckingInspection
class LteChannelBandwidth(Enum):
	"""4 Members, F10M ... F5M"""
	F10M = 0
	F20M = 1
	F3M = 2
	F5M = 3


# noinspection SpellCheckingInspection
class MagnitudeUnit(Enum):
	"""2 Members, RAW ... VOLT"""
	RAW = 0
	VOLT = 1


# noinspection SpellCheckingInspection
class MarkerFunction(Enum):
	"""6 Members, MAX ... MIN"""
	MAX = 0
	MAXL = 1
	MAXN = 2
	MAXR = 3
	MAXV = 4
	MIN = 5


# noinspection SpellCheckingInspection
class MarkerPlacement(Enum):
	"""2 Members, ABSolute ... RELative"""
	ABSolute = 0
	RELative = 1


# noinspection SpellCheckingInspection
class MeasAccuracy(Enum):
	"""2 Members, HIGH ... NORMal"""
	HIGH = 0
	NORMal = 1


# noinspection SpellCheckingInspection
class MeasState(Enum):
	"""10 Members, ACTive ... RUN"""
	ACTive = 0
	ADJusted = 1
	ALIVe = 2
	FROZen = 3
	INValid = 4
	OFF = 5
	PENDing = 6
	QUEued = 7
	RDY = 8
	RUN = 9


# noinspection SpellCheckingInspection
class ModulationScheme(Enum):
	"""8 Members, AM ... USB"""
	AM = 0
	ARB = 1
	CW = 2
	FM = 3
	FMSTereo = 4
	LSB = 5
	PM = 6
	USB = 7


# noinspection SpellCheckingInspection
class NotchPath(Enum):
	"""3 Members, AF ... VOIP"""
	AF = 0
	SPDif = 1
	VOIP = 2


# noinspection SpellCheckingInspection
class NrtDevice(Enum):
	"""3 Members, N14 ... N44"""
	N14 = 0
	N43 = 1
	N44 = 2


# noinspection SpellCheckingInspection
class NxdnPattern(Enum):
	"""14 Members, P1011 ... SILence"""
	P1011 = 0
	P1031 = 1
	PRBS15 = 2
	PRBS9 = 3
	R10A = 4
	RA0 = 5
	RA1 = 6
	RAW1 = 7
	RAW2 = 8
	RLD = 9
	RPRB15 = 10
	RPRB9 = 11
	RSYR = 12
	SILence = 13


# noinspection SpellCheckingInspection
class NxdnPatternB(Enum):
	"""13 Members, CUST ... STD1"""
	CUST = 0
	P1031 = 1
	PRBS9 = 2
	R1031 = 3
	R10A = 4
	RA0 = 5
	RA1 = 6
	RLD = 7
	RPRB15 = 8
	RPRB9 = 9
	RSYR = 10
	SILence = 11
	STD1 = 12


# noinspection SpellCheckingInspection
class OperationMode(Enum):
	"""2 Members, LOCal ... REMote"""
	LOCal = 0
	REMote = 1


# noinspection SpellCheckingInspection
class OptionsProductType(Enum):
	"""5 Members, ALL ... SWPackage"""
	ALL = 0
	FWA = 1
	HWOPtion = 2
	SWOPtion = 3
	SWPackage = 4


# noinspection SpellCheckingInspection
class OptionsScope(Enum):
	"""2 Members, INSTrument ... SYSTem"""
	INSTrument = 0
	SYSTem = 1


# noinspection SpellCheckingInspection
class OptionValidity(Enum):
	"""4 Members, ALL ... VALid"""
	ALL = 0
	CLICense = 1
	FUNCtional = 2
	VALid = 3


# noinspection SpellCheckingInspection
class OscillatorType(Enum):
	"""2 Members, OCXO ... TCXO"""
	OCXO = 0
	TCXO = 1


# noinspection SpellCheckingInspection
class OutputConnector(Enum):
	"""2 Members, RFCom ... RFOut"""
	RFCom = 0
	RFOut = 1


# noinspection SpellCheckingInspection
class OverviewType(Enum):
	"""3 Members, FFT ... OSCilloscope"""
	FFT = 0
	NONE = 1
	OSCilloscope = 2


# noinspection SpellCheckingInspection
class P25Mode(Enum):
	"""2 Members, C4FM ... CQPSk"""
	C4FM = 0
	CQPSk = 1


# noinspection SpellCheckingInspection
class P25Pattern(Enum):
	"""15 Members, BUSY ... SILence"""
	BUSY = 0
	C4FM = 1
	CALibration = 2
	IDLE = 3
	INTerference = 4
	P1011 = 5
	R10A = 6
	RA0 = 7
	RA1 = 8
	RAW1 = 9
	RLD = 10
	RPRB15 = 11
	RPRB9 = 12
	RSYR = 13
	SILence = 14


# noinspection SpellCheckingInspection
class PagerType(Enum):
	"""3 Members, ALPHanumeric ... TONLy"""
	ALPHanumeric = 0
	NUMeric = 1
	TONLy = 2


# noinspection SpellCheckingInspection
class PathCoupling(Enum):
	"""2 Members, AC ... DC"""
	AC = 0
	DC = 1


# noinspection SpellCheckingInspection
class PowerMode(Enum):
	"""4 Members, ALL ... SWEep"""
	ALL = 0
	ONCE = 1
	PRESelect = 2
	SWEep = 3


# noinspection SpellCheckingInspection
class PowerSignalDirection(Enum):
	"""3 Members, AUTO ... REV"""
	AUTO = 0
	FWD = 1
	REV = 2


# noinspection SpellCheckingInspection
class PreDeEmphasis(Enum):
	"""4 Members, OFF ... T750"""
	OFF = 0
	T50 = 1
	T75 = 2
	T750 = 3


# noinspection SpellCheckingInspection
class ProtocolMode(Enum):
	"""3 Members, AGILent ... RAW"""
	AGILent = 0
	IEEE1174 = 1
	RAW = 2


# noinspection SpellCheckingInspection
class PtFiveFilter(Enum):
	"""2 Members, C4FM ... RC"""
	C4FM = 0
	RC = 1


# noinspection SpellCheckingInspection
class PulseShapingFilter(Enum):
	"""1 Members, RRC ... RRC"""
	RRC = 0


# noinspection SpellCheckingInspection
class PulseShapingUserFilter(Enum):
	"""5 Members, COS ... SINC"""
	COS = 0
	GAUSs = 1
	NXRX = 2
	RRC = 3
	SINC = 4


# noinspection SpellCheckingInspection
class PwrFilterType(Enum):
	"""2 Members, NARRow ... WIDE"""
	NARRow = 0
	WIDE = 1


# noinspection SpellCheckingInspection
class RbwFilterType(Enum):
	"""2 Members, BANDpass ... GAUSs"""
	BANDpass = 0
	GAUSs = 1


# noinspection SpellCheckingInspection
class RefFreqSource(Enum):
	"""3 Members, EXTernal ... INV"""
	EXTernal = 0
	INTernal = 1
	INV = 2


# noinspection SpellCheckingInspection
class Relative(Enum):
	"""2 Members, CONStant ... RELative"""
	CONStant = 0
	RELative = 1


# noinspection SpellCheckingInspection
class Repeat(Enum):
	"""2 Members, CONTinuous ... SINGleshot"""
	CONTinuous = 0
	SINGleshot = 1


# noinspection SpellCheckingInspection
class RepeatMode(Enum):
	"""2 Members, CONTinuous ... SINGle"""
	CONTinuous = 0
	SINGle = 1


# noinspection SpellCheckingInspection
class ResourceState(Enum):
	"""8 Members, ACTive ... RUN"""
	ACTive = 0
	ADJusted = 1
	INValid = 2
	OFF = 3
	PENDing = 4
	QUEued = 5
	RDY = 6
	RUN = 7


# noinspection SpellCheckingInspection
class ResultStatus(Enum):
	"""11 Members, DC ... ULEU"""
	DC = 0
	INV = 1
	NAV = 2
	NCAP = 3
	OFF = 4
	OFL = 5
	OK = 6
	ON = 7
	UFL = 8
	ULEL = 9
	ULEU = 10


# noinspection SpellCheckingInspection
class ScreenshotFormat(Enum):
	"""3 Members, BMP ... PNG"""
	BMP = 0
	JPG = 1
	PNG = 2


# noinspection SpellCheckingInspection
class SearchExtent(Enum):
	"""3 Members, FULL ... ONLevel"""
	FULL = 0
	OFFLevel = 1
	ONLevel = 2


# noinspection SpellCheckingInspection
class SearchRoutine(Enum):
	"""5 Members, RIFBandwidth ... TSENsitivity"""
	RIFBandwidth = 0
	RSENsitivity = 1
	RSQuelch = 2
	SSNR = 3
	TSENsitivity = 4


# noinspection SpellCheckingInspection
class SearchRoutinePath(Enum):
	"""3 Members, AFI1 ... VOIP"""
	AFI1 = 0
	AFI2 = 1
	VOIP = 2


# noinspection SpellCheckingInspection
class SelCallStandard(Enum):
	"""8 Members, CCIR ... ZVEI3"""
	CCIR = 0
	DZVei = 1
	EEA = 2
	EIA = 3
	PZVei = 4
	ZVEI1 = 5
	ZVEI2 = 6
	ZVEI3 = 7


# noinspection SpellCheckingInspection
class SignalSlope(Enum):
	"""2 Members, FEDGe ... REDGe"""
	FEDGe = 0
	REDGe = 1


# noinspection SpellCheckingInspection
class SignalSlopeExt(Enum):
	"""4 Members, FALLing ... RISing"""
	FALLing = 0
	FEDGe = 1
	REDGe = 2
	RISing = 3


# noinspection SpellCheckingInspection
class SignalSource(Enum):
	"""14 Members, AFI1 ... SPIR"""
	AFI1 = 0
	AFI2 = 1
	AFIB = 2
	FCHL = 3
	FCHR = 4
	FILE = 5
	GEN1 = 6
	GEN2 = 7
	GEN3 = 8
	GEN4 = 9
	GENB = 10
	SPIL = 11
	SPIN = 12
	SPIR = 13


# noinspection SpellCheckingInspection
class SingDualTonesType(Enum):
	"""2 Members, DTONes ... STONes"""
	DTONes = 0
	STONes = 1


# noinspection SpellCheckingInspection
class SingDualToneType(Enum):
	"""2 Members, DTONe ... STONe"""
	DTONe = 0
	STONe = 1


# noinspection SpellCheckingInspection
class SipState(Enum):
	"""3 Members, ERRor ... TERMinated"""
	ERRor = 0
	ESTablished = 1
	TERMinated = 2


# noinspection SpellCheckingInspection
class SoundSource(Enum):
	"""6 Members, AFONe ... SPDif"""
	AFONe = 0
	DEModulator = 1
	GENone = 2
	GENThree = 3
	LAN = 4
	SPDif = 5


# noinspection SpellCheckingInspection
class Source(Enum):
	"""1 Members, TTLin ... TTLin"""
	TTLin = 0


# noinspection SpellCheckingInspection
class SpanMode(Enum):
	"""2 Members, FSWeep ... ZSPan"""
	FSWeep = 0
	ZSPan = 1


# noinspection SpellCheckingInspection
class SpecAnApp(Enum):
	"""2 Members, FREQ ... ZERO"""
	FREQ = 0
	ZERO = 1


# noinspection SpellCheckingInspection
class Standard(Enum):
	"""8 Members, CUSTom ... TETRa"""
	CUSTom = 0
	DMR = 1
	DPMR = 2
	LTE = 3
	NXDN = 4
	P25 = 5
	SPECtrum = 6
	TETRa = 7


# noinspection SpellCheckingInspection
class Statistic(Enum):
	"""4 Members, AVERage ... MINimum"""
	AVERage = 0
	CURRent = 1
	MAXimum = 2
	MINimum = 3


# noinspection SpellCheckingInspection
class StatRegFormat(Enum):
	"""4 Members, ASCii ... OCTal"""
	ASCii = 0
	BINary = 1
	HEXadecimal = 2
	OCTal = 3


# noinspection SpellCheckingInspection
class Status(Enum):
	"""2 Members, FAILed ... PASSed"""
	FAILed = 0
	PASSed = 1


# noinspection SpellCheckingInspection
class StopCondition(Enum):
	"""2 Members, NONE ... SLFail"""
	NONE = 0
	SLFail = 1


# noinspection SpellCheckingInspection
class SubTab(Enum):
	"""9 Members, AFResults ... TRIM"""
	AFResults = 0
	FFT = 1
	FMSTereo = 2
	MULTitone = 3
	OSC = 4
	OVERview = 5
	RFResults = 6
	TONes = 7
	TRIM = 8


# noinspection SpellCheckingInspection
class SupplyMode(Enum):
	"""2 Members, BATTery ... MAINs"""
	BATTery = 0
	MAINs = 1


# noinspection SpellCheckingInspection
class TabSplit(Enum):
	"""2 Members, SPLit ... TAB"""
	SPLit = 0
	TAB = 1


# noinspection SpellCheckingInspection
class TargetParType(Enum):
	"""4 Members, SINad ... SNRatio"""
	SINad = 0
	SNDNratio = 1
	SNNRatio = 2
	SNRatio = 3


# noinspection SpellCheckingInspection
class TestPlanState(Enum):
	"""10 Members, EDITmode ... SERRor"""
	EDITmode = 0
	FINished = 1
	IDLE = 2
	LOADing = 3
	NOAVailable = 4
	NOLoaded = 5
	OPTMissing = 6
	PAUSed = 7
	RUNNing = 8
	SERRor = 9


# noinspection SpellCheckingInspection
class TimeoutMode(Enum):
	"""2 Members, AUTO ... MANU"""
	AUTO = 0
	MANU = 1


# noinspection SpellCheckingInspection
class ToneMode(Enum):
	"""4 Members, NOISe ... STONe"""
	NOISe = 0
	NONE = 1
	SQUare = 2
	STONe = 3


# noinspection SpellCheckingInspection
class ToneTypeA(Enum):
	"""9 Members, DTMF ... STONe"""
	DTMF = 0
	DTONe = 1
	FDIaling = 2
	MTONe = 3
	NOISe = 4
	SCAL = 5
	SELCall = 6
	SQUare = 7
	STONe = 8


# noinspection SpellCheckingInspection
class ToneTypeB(Enum):
	"""4 Members, CTCSs ... SUBTone"""
	CTCSs = 0
	DCS = 1
	NONE = 2
	SUBTone = 3


# noinspection SpellCheckingInspection
class TraceB(Enum):
	"""5 Members, AVERage ... TDOMmain"""
	AVERage = 0
	CURRent = 1
	MAXimum = 2
	MINimum = 3
	TDOMmain = 4


# noinspection SpellCheckingInspection
class TraceC(Enum):
	"""3 Members, AVERage ... MAXimum"""
	AVERage = 0
	CURRent = 1
	MAXimum = 2


# noinspection SpellCheckingInspection
class Transmission(Enum):
	"""3 Members, EFR9600 ... EHR9600"""
	EFR9600 = 0
	EHR4800 = 1
	EHR9600 = 2


# noinspection SpellCheckingInspection
class TriggerCouplingAin(Enum):
	"""4 Members, DEMod ... VOIP"""
	DEMod = 0
	NONE = 1
	SIN = 2
	VOIP = 3


# noinspection SpellCheckingInspection
class TriggerCouplingDemod(Enum):
	"""4 Members, AIN ... VOIP"""
	AIN = 0
	NONE = 1
	SIN = 2
	VOIP = 3


# noinspection SpellCheckingInspection
class TriggerCouplingDigital(Enum):
	"""3 Members, AIN ... NONE"""
	AIN = 0
	DEMod = 1
	NONE = 2


# noinspection SpellCheckingInspection
class TriggerMode(Enum):
	"""4 Members, AUTO ... SINGle"""
	AUTO = 0
	FRUN = 1
	NORMal = 2
	SINGle = 3


# noinspection SpellCheckingInspection
class TriggerSourceAf(Enum):
	"""2 Members, AF1 ... AF2"""
	AF1 = 0
	AF2 = 1


# noinspection SpellCheckingInspection
class TriggerSourceDemod(Enum):
	"""3 Members, DEMod ... RIGHt"""
	DEMod = 0
	LEFT = 1
	RIGHt = 2


# noinspection SpellCheckingInspection
class TxAfSource(Enum):
	"""3 Members, AF1O ... VOIP"""
	AF1O = 0
	AF2O = 1
	VOIP = 2


# noinspection SpellCheckingInspection
class UpDownDirection(Enum):
	"""2 Members, DOWN ... UP"""
	DOWN = 0
	UP = 1


# noinspection SpellCheckingInspection
class UserDefPattern(Enum):
	"""2 Members, PRBS6 ... PRBS9"""
	PRBS6 = 0
	PRBS9 = 1


# noinspection SpellCheckingInspection
class UserRole(Enum):
	"""5 Members, ADMin ... USER"""
	ADMin = 0
	DEVeloper = 1
	SERVice = 2
	UEXTended = 3
	USER = 4


# noinspection SpellCheckingInspection
class VoIpCodec(Enum):
	"""2 Members, ALAW ... ULAW"""
	ALAW = 0
	ULAW = 1


# noinspection SpellCheckingInspection
class VoIpSource(Enum):
	"""6 Members, AFI1 ... SPIR"""
	AFI1 = 0
	AFI2 = 1
	GEN3 = 2
	GEN4 = 3
	SPIL = 4
	SPIR = 5


# noinspection SpellCheckingInspection
class VphaseDirection(Enum):
	"""2 Members, FROM ... TO"""
	FROM = 0
	TO = 1


# noinspection SpellCheckingInspection
class WeightingFilter(Enum):
	"""4 Members, AWEighting ... OFF"""
	AWEighting = 0
	CCITt = 1
	CMESsage = 2
	OFF = 3


# noinspection SpellCheckingInspection
class Xdivision(Enum):
	"""19 Members, M1 ... U500"""
	M1 = 0
	M10 = 1
	M100 = 2
	M2 = 3
	M20 = 4
	M200 = 5
	M5 = 6
	M50 = 7
	M500 = 8
	S1 = 9
	U1 = 10
	U10 = 11
	U100 = 12
	U2 = 13
	U20 = 14
	U200 = 15
	U5 = 16
	U50 = 17
	U500 = 18


# noinspection SpellCheckingInspection
class XrtInputConnector(Enum):
	"""8 Members, RF1 ... RF8"""
	RF1 = 0
	RF2 = 1
	RF3 = 2
	RF4 = 3
	RF5 = 4
	RF6 = 5
	RF7 = 6
	RF8 = 7


# noinspection SpellCheckingInspection
class YesNoStatus(Enum):
	"""2 Members, NO ... YES"""
	NO = 0
	YES = 1


# noinspection SpellCheckingInspection
class ZigBeeMode(Enum):
	"""1 Members, OQPSk ... OQPSk"""
	OQPSk = 0



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Counter:
	"""Counter commands group definition. 4 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("counter", core, parent)

	@property
	def freqError(self):
		"""freqError commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_freqError'):
			from .Counter_.FreqError import FreqError
			self._freqError = FreqError(self._core, self._base)
		return self._freqError

	def initiate(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:FREQuency:COUNter \n
		Snippet: driver.afRf.measurement.frequency.counter.initiate() \n
		Starts the search procedure to find an RF signal. \n
		"""
		self._core.io.write(f'INITiate:AFRF:MEASurement<Instance>:FREQuency:COUNter')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:FREQuency:COUNter \n
		Snippet: driver.afRf.measurement.frequency.counter.initiate_with_opc() \n
		Starts the search procedure to find an RF signal. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:AFRF:MEASurement<Instance>:FREQuency:COUNter')

	def abort(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:FREQuency:COUNter \n
		Snippet: driver.afRf.measurement.frequency.counter.abort() \n
		Aborts the search procedure for an RF signal. The configured RF settings are not modified. \n
		"""
		self._core.io.write(f'ABORt:AFRF:MEASurement<Instance>:FREQuency:COUNter')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:FREQuency:COUNter \n
		Snippet: driver.afRf.measurement.frequency.counter.abort_with_opc() \n
		Aborts the search procedure for an RF signal. The configured RF settings are not modified. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:AFRF:MEASurement<Instance>:FREQuency:COUNter')

	# noinspection PyTypeChecker
	class FetchStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Frequency: float: Frequency of signal peak Range: 0 Hz to 3 GHz, Unit: Hz
			- Level: float: Power of signal peak Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Frequency'),
			ArgStruct.scalar_float('Level')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Frequency: float = None
			self.Level: float = None

	def fetch(self) -> FetchStruct:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:FREQuency:COUNter \n
		Snippet: value: FetchStruct = driver.afRf.measurement.frequency.counter.fetch() \n
		Queries the search procedure results. \n
			:return: structure: for return value, see the help for FetchStruct structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:FREQuency:COUNter?', self.__class__.FetchStruct())

	def clone(self) -> 'Counter':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Counter(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserDefined:
	"""UserDefined commands group definition. 12 total commands, 0 Sub-groups, 12 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("userDefined", core, parent)

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.RepeatMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:REPetition \n
		Snippet: value: enums.RepeatMode = driver.source.afRf.generator.userDefined.get_repetition() \n
		Specifies how often the bit sequence is processed for the user-defined standard. \n
			:return: repetition: CONTinuous | SINGle SINGleshot: Single transmission of the bit sequence CONTinuous: Continuous repetition of the bit sequence
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.RepeatMode)

	def set_repetition(self, repetition: enums.RepeatMode) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:REPetition \n
		Snippet: driver.source.afRf.generator.userDefined.set_repetition(repetition = enums.RepeatMode.CONTinuous) \n
		Specifies how often the bit sequence is processed for the user-defined standard. \n
			:param repetition: CONTinuous | SINGle SINGleshot: Single transmission of the bit sequence CONTinuous: Continuous repetition of the bit sequence
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.RepeatMode)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:REPetition {param}')

	def get_pause(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:PAUSe \n
		Snippet: value: float = driver.source.afRf.generator.userDefined.get_pause() \n
		Defines the duration of a pause between two repetitions of a bit sequence for the user-defined standard. \n
			:return: pause: Range: 0 ms to 10E+3 ms, Unit: s
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:PAUSe?')
		return Conversions.str_to_float(response)

	def set_pause(self, pause: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:PAUSe \n
		Snippet: driver.source.afRf.generator.userDefined.set_pause(pause = 1.0) \n
		Defines the duration of a pause between two repetitions of a bit sequence for the user-defined standard. \n
			:param pause: Range: 0 ms to 10E+3 ms, Unit: s
		"""
		param = Conversions.decimal_value_to_str(pause)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:PAUSe {param}')

	def get_bandwidth(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:BANDwidth \n
		Snippet: value: float = driver.source.afRf.generator.userDefined.get_bandwidth() \n
		Selects the bandwidth of the Gauss filter for pulse shaping for the user-defined standard. \n
			:return: bandwidth: Range: 1000 Hz to 100000 Hz
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:BANDwidth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bandwidth: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:BANDwidth \n
		Snippet: driver.source.afRf.generator.userDefined.set_bandwidth(bandwidth = 1.0) \n
		Selects the bandwidth of the Gauss filter for pulse shaping for the user-defined standard. \n
			:param bandwidth: Range: 1000 Hz to 100000 Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:BANDwidth {param}')

	# noinspection PyTypeChecker
	def get_ilength(self) -> enums.ImpulseLength:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:ILENgth \n
		Snippet: value: enums.ImpulseLength = driver.source.afRf.generator.userDefined.get_ilength() \n
		Selects the impulse length of the filter used for pulse shaping for the user-defined standard. \n
			:return: impulse_length: T | T2 | T4 | T6 | T8
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:ILENgth?')
		return Conversions.str_to_scalar_enum(response, enums.ImpulseLength)

	def set_ilength(self, impulse_length: enums.ImpulseLength) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:ILENgth \n
		Snippet: driver.source.afRf.generator.userDefined.set_ilength(impulse_length = enums.ImpulseLength.T) \n
		Selects the impulse length of the filter used for pulse shaping for the user-defined standard. \n
			:param impulse_length: T | T2 | T4 | T6 | T8
		"""
		param = Conversions.enum_scalar_to_str(impulse_length, enums.ImpulseLength)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:ILENgth {param}')

	def get_ro_factor(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:ROFactor \n
		Snippet: value: float = driver.source.afRf.generator.userDefined.get_ro_factor() \n
		Specifies the roll-off factor of the filter used for pulse shaping for the user-defined standard. \n
			:return: ro_factor: Range: 0 to 1
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:ROFactor?')
		return Conversions.str_to_float(response)

	def set_ro_factor(self, ro_factor: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:ROFactor \n
		Snippet: driver.source.afRf.generator.userDefined.set_ro_factor(ro_factor = 1.0) \n
		Specifies the roll-off factor of the filter used for pulse shaping for the user-defined standard. \n
			:param ro_factor: Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(ro_factor)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:ROFactor {param}')

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.GeneratorFilter:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:FILTer \n
		Snippet: value: enums.GeneratorFilter = driver.source.afRf.generator.userDefined.get_filter_py() \n
		Selects a filter type for pulse shaping for the user-defined standard. \n
			:return: filter_py: GAUSs | RRC | RC | COS | SINC
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorFilter)

	def set_filter_py(self, filter_py: enums.GeneratorFilter) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:FILTer \n
		Snippet: driver.source.afRf.generator.userDefined.set_filter_py(filter_py = enums.GeneratorFilter.COS) \n
		Selects a filter type for pulse shaping for the user-defined standard. \n
			:param filter_py: GAUSs | RRC | RC | COS | SINC
		"""
		param = Conversions.enum_scalar_to_str(filter_py, enums.GeneratorFilter)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:FILTer {param}')

	def get_slength(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:SLENgth \n
		Snippet: value: int = driver.source.afRf.generator.userDefined.get_slength() \n
		Specifies the length of a single bit sequence for the user-defined standard. \n
			:return: slength: Range: 0 bits to 16320 bits, Unit: bits
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, slength: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:SLENgth \n
		Snippet: driver.source.afRf.generator.userDefined.set_slength(slength = 1) \n
		Specifies the length of a single bit sequence for the user-defined standard. \n
			:param slength: Range: 0 bits to 16320 bits, Unit: bits
		"""
		param = Conversions.decimal_value_to_str(slength)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:SLENgth {param}')

	def get_drate(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:DRATe \n
		Snippet: value: int = driver.source.afRf.generator.userDefined.get_drate() \n
		Specifies the data rate for the user-defined standard. \n
			:return: drate: Range: 200 bit/s to 115200 bit/s, Unit: bit/s
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:DRATe?')
		return Conversions.str_to_int(response)

	def set_drate(self, drate: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:DRATe \n
		Snippet: driver.source.afRf.generator.userDefined.set_drate(drate = 1) \n
		Specifies the data rate for the user-defined standard. \n
			:param drate: Range: 200 bit/s to 115200 bit/s, Unit: bit/s
		"""
		param = Conversions.decimal_value_to_str(drate)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:DRATe {param}')

	def get_svalue(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:SVALue \n
		Snippet: value: str = driver.source.afRf.generator.userDefined.get_svalue() \n
		Specifies the seed value for the PRBS generator, for the user-defined standard. \n
			:return: svalue: Range: #H0 to #H1FF (for PRBS 6 max. #H3F)
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:SVALue?')
		return trim_str_response(response)

	def set_svalue(self, svalue: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:SVALue \n
		Snippet: driver.source.afRf.generator.userDefined.set_svalue(svalue = r1) \n
		Specifies the seed value for the PRBS generator, for the user-defined standard. \n
			:param svalue: Range: #H0 to #H1FF (for PRBS 6 max. #H3F)
		"""
		param = Conversions.value_to_str(svalue)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:SVALue {param}')

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.UserDefPattern:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:PATTern \n
		Snippet: value: enums.UserDefPattern = driver.source.afRf.generator.userDefined.get_pattern() \n
		Selects the bit pattern to be transmitted as payload for the user-defined standard. \n
			:return: pattern: PRBS6 | PRBS9
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.UserDefPattern)

	def set_pattern(self, pattern: enums.UserDefPattern) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:PATTern \n
		Snippet: driver.source.afRf.generator.userDefined.set_pattern(pattern = enums.UserDefPattern.PRBS6) \n
		Selects the bit pattern to be transmitted as payload for the user-defined standard. \n
			:param pattern: PRBS6 | PRBS9
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.UserDefPattern)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:PATTern {param}')

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.userDefined.get_standard_dev() \n
		Defines the frequency deviations for the 4FSK modulation of the user-defined standard. A setting command defines the
		deviation for symbol 01. The deviations for the other symbols are calculated from the setting. A query returns a
		comma-separated list of four deviations, for symbol 01, 00, 10, 11. \n
			:return: sdeviation: Frequency deviation Range: -100 kHz to 100 kHz, Unit: Hz
		"""
		response = self._core.io.query_bin_or_ascii_float_list_with_opc('SOURce:AFRF:GENerator<Instance>:UDEFined:SDEViation?')
		return response

	def set_standard_dev(self, sdeviation: List[float]) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:SDEViation \n
		Snippet: driver.source.afRf.generator.userDefined.set_standard_dev(sdeviation = [1.1, 2.2, 3.3]) \n
		Defines the frequency deviations for the 4FSK modulation of the user-defined standard. A setting command defines the
		deviation for symbol 01. The deviations for the other symbols are calculated from the setting. A query returns a
		comma-separated list of four deviations, for symbol 01, 00, 10, 11. \n
			:param sdeviation: Frequency deviation Range: -100 kHz to 100 kHz, Unit: Hz
		"""
		param = Conversions.list_to_csv_str(sdeviation)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:UDEFined:SDEViation {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FskMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:UDEFined:MODE \n
		Snippet: value: enums.FskMode = driver.source.afRf.generator.userDefined.get_mode() \n
		Queries the modulation type for the user-defined standard. \n
			:return: mode: 4FSK
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:UDEFined:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FskMode)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Item:
	"""Item commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("item", core, parent)

	def set(self, item_path: str, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:ITEM \n
		Snippet: driver.massMemory.load.item.set(item_path = '1', filename = '1') \n
		No command help available \n
			:param item_path: No help available
			:param filename: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('item_path', item_path, DataType.String), ArgSingle('filename', filename, DataType.String))
		self._core.io.write(f'MMEMory:LOAD:ITEM {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.Utilities import trim_str_response
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Next:
	"""Next commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("next", core, parent)

	def get(self, filter_py: str = None, mode: enums.ExpressionMode = None) -> str:
		"""SCPI: STATus:EVENt:BITS:NEXT \n
		Snippet: value: str = driver.status.event.bits.next.get(filter_py = '1', mode = enums.ExpressionMode.REGex) \n
		No command help available \n
			:param filter_py: No help available
			:param mode: No help available
			:return: bit: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('filter_py', filter_py, DataType.String, True), ArgSingle('mode', mode, DataType.Enum, True))
		response = self._core.io.query_str(f'STATus:EVENt:BITS:NEXT? {param}'.rstrip())
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZeroSpan:
	"""ZeroSpan commands group definition. 8 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zeroSpan", core, parent)

	@property
	def rbw(self):
		"""rbw commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_rbw'):
			from .ZeroSpan_.Rbw import Rbw
			self._rbw = Rbw(self._core, self._base)
		return self._rbw

	@property
	def vbw(self):
		"""vbw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_vbw'):
			from .ZeroSpan_.Vbw import Vbw
			self._vbw = Vbw(self._core, self._base)
		return self._vbw

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .ZeroSpan_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	def get_swt(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:SWT \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.zeroSpan.get_swt() \n
		Specifies the sweep time for the zero span mode. \n
			:return: sweep_time: Range: 500.5E-6 s to 2000 s, Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:SWT?')
		return Conversions.str_to_float(response)

	def set_swt(self, sweep_time: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:SWT \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.set_swt(sweep_time = 1.0) \n
		Specifies the sweep time for the zero span mode. \n
			:param sweep_time: Range: 500.5E-6 s to 2000 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(sweep_time)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:SWT {param}')

	def clone(self) -> 'ZeroSpan':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ZeroSpan(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vbw:
	"""Vbw commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("vbw", core, parent)

	def get_auto(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW:AUTO \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.zeroSpan.vbw.get_auto() \n
		Enables or disables automatic configuration of the video bandwidth (VBW) for the zero span mode. \n
			:return: vbw_auto: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW:AUTO?')
		return Conversions.str_to_bool(response)

	def set_auto(self, vbw_auto: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW:AUTO \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.vbw.set_auto(vbw_auto = False) \n
		Enables or disables automatic configuration of the video bandwidth (VBW) for the zero span mode. \n
			:param vbw_auto: OFF | ON
		"""
		param = Conversions.bool_to_str(vbw_auto)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW:AUTO {param}')

	def get_value(self) -> float or bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW \n
		Snippet: value: float or bool = driver.configure.gprfMeasurement.spectrum.zeroSpan.vbw.get_value() \n
		Selects the bandwidth of the video filter for the zero span mode. Setting this value is only possible if the automatic
		VBW selection is switched off, see method RsCma.Configure.GprfMeasurement.Spectrum.ZeroSpan.Vbw.auto. \n
			:return: vbw: You can enter values between 10 Hz and 10 MHz. The setting is rounded to the closest of the following values: 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 Hz 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 2 / 3 / 5 / 10 MHz OFF disables the filter Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW?')
		return Conversions.str_to_float_or_bool(response)

	def set_value(self, vbw: float or bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.vbw.set_value(vbw = 1.0) \n
		Selects the bandwidth of the video filter for the zero span mode. Setting this value is only possible if the automatic
		VBW selection is switched off, see method RsCma.Configure.GprfMeasurement.Spectrum.ZeroSpan.Vbw.auto. \n
			:param vbw: You can enter values between 10 Hz and 10 MHz. The setting is rounded to the closest of the following values: 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 Hz 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 2 / 3 / 5 / 10 MHz OFF disables the filter Unit: Hz
		"""
		param = Conversions.decimal_or_bool_value_to_str(vbw)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:VBW {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Average:
	"""Average commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("average", core, parent)

	def get_aperture(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:AVERage:APERture \n
		Snippet: value: float = driver.configure.gprfMeasurement.extPwrSensor.average.get_aperture() \n
		Defines the size of the acquisition interval. \n
			:return: aperture: Range: 10E-6 s to 0.3 s, Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:AVERage:APERture?')
		return Conversions.str_to_float(response)

	def set_aperture(self, aperture: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:AVERage:APERture \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.average.set_aperture(aperture = 1.0) \n
		Defines the size of the acquisition interval. \n
			:param aperture: Range: 10E-6 s to 0.3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(aperture)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:AVERage:APERture {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Zbox:
	"""Zbox commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zbox", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:BASE:ZBOX:ENABle \n
		Snippet: value: bool = driver.configure.base.zbox.get_enable() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('CONFigure:BASE:ZBOX:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:BASE:ZBOX:ENABle \n
		Snippet: driver.configure.base.zbox.set_enable(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:BASE:ZBOX:ENABle {param}')

	# noinspection PyTypeChecker
	def get_impedance(self) -> enums.Impedance:
		"""SCPI: CONFigure:BASE:ZBOX:IMPedance \n
		Snippet: value: enums.Impedance = driver.configure.base.zbox.get_impedance() \n
		No command help available \n
			:return: impedance: No help available
		"""
		response = self._core.io.query_str('CONFigure:BASE:ZBOX:IMPedance?')
		return Conversions.str_to_scalar_enum(response, enums.Impedance)

	def set_impedance(self, impedance: enums.Impedance) -> None:
		"""SCPI: CONFigure:BASE:ZBOX:IMPedance \n
		Snippet: driver.configure.base.zbox.set_impedance(impedance = enums.Impedance.IHOL) \n
		No command help available \n
			:param impedance: No help available
		"""
		param = Conversions.enum_scalar_to_str(impedance, enums.Impedance)
		self._core.io.write(f'CONFigure:BASE:ZBOX:IMPedance {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Out:
	"""Out commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("out", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Out_.Catalog import Catalog
			self._catalog = Catalog(self._core, self._base)
		return self._catalog

	def get_source(self) -> str:
		"""SCPI: TRIGger:BASE:OUT:SOURce \n
		Snippet: value: str = driver.trigger.base.out.get_source() \n
		Selects the output trigger signal to be routed to the TRIG OUT connector. \n
			:return: source: Source as string, examples: 'No Connection' TRIG OUT connector deactivated 'Base1: External TRIG In' Trigger signal from TRIG IN connector 'AFRF Gen1: ...' Trigger signal from processed waveform file
		"""
		response = self._core.io.query_str('TRIGger:BASE:OUT:SOURce?')
		return trim_str_response(response)

	def set_source(self, source: str) -> None:
		"""SCPI: TRIGger:BASE:OUT:SOURce \n
		Snippet: driver.trigger.base.out.set_source(source = '1') \n
		Selects the output trigger signal to be routed to the TRIG OUT connector. \n
			:param source: Source as string, examples: 'No Connection' TRIG OUT connector deactivated 'Base1: External TRIG In' Trigger signal from TRIG IN connector 'AFRF Gen1: ...' Trigger signal from processed waveform file
		"""
		param = Conversions.value_to_quoted_str(source)
		self._core.io.write(f'TRIGger:BASE:OUT:SOURce {param}')

	def clone(self) -> 'Out':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Out(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Internal:
	"""Internal commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("internal", core, parent)

	# noinspection PyTypeChecker
	def get_li_range(self) -> enums.LockRangeInternal:
		"""SCPI: SYSTem:BASE:REFerence:INTernal:LIRange \n
		Snippet: value: enums.LockRangeInternal = driver.system.base.reference.internal.get_li_range() \n
		Selects the type of an internal reference frequency source. \n
			:return: li_range: MEDium | NARRow | INV MEDium TCXO NARRow OCXO INV Source unusable, for example adjustment ongoing
		"""
		response = self._core.io.query_str_with_opc('SYSTem:BASE:REFerence:INTernal:LIRange?')
		return Conversions.str_to_scalar_enum(response, enums.LockRangeInternal)

	def set_li_range(self, li_range: enums.LockRangeInternal) -> None:
		"""SCPI: SYSTem:BASE:REFerence:INTernal:LIRange \n
		Snippet: driver.system.base.reference.internal.set_li_range(li_range = enums.LockRangeInternal.INV) \n
		Selects the type of an internal reference frequency source. \n
			:param li_range: MEDium | NARRow | INV MEDium TCXO NARRow OCXO INV Source unusable, for example adjustment ongoing
		"""
		param = Conversions.enum_scalar_to_str(li_range, enums.LockRangeInternal)
		self._core.io.write_with_opc(f'SYSTem:BASE:REFerence:INTernal:LIRange {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Maximum:
	"""Maximum commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("maximum", core, parent)

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Rms: float: RMS average value Unit: Hz
			- Rms_Sqrt_2: float: RMS result multiplied with the square root of 2 Unit: Hz
			- Ppeak: float: Positive peak value Unit: Hz
			- Mpeak: float: Negative peak value Unit: Hz
			- Mp_Peak_Average: enums.ResultStatus: Peak-to-peak value divided by 2 Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Rms'),
			ArgStruct.scalar_float('Rms_Sqrt_2'),
			ArgStruct.scalar_float('Ppeak'),
			ArgStruct.scalar_float('Mpeak'),
			ArgStruct.scalar_enum('Mp_Peak_Average', enums.ResultStatus)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Rms: float = None
			self.Rms_Sqrt_2: float = None
			self.Ppeak: float = None
			self.Mpeak: float = None
			self.Mp_Peak_Average: enums.ResultStatus = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FDEViation:MAXimum \n
		Snippet: value: CalculateStruct = driver.afRf.measurement.multiEval.demodulation.fdeviation.maximum.calculate() \n
		Queries the demodulation results for FM or FM stereo demodulation. A statistical evaluation of the frequency deviation or
		multiplex deviation is returned. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FDEViation:MAXimum?', self.__class__.CalculateStruct())

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Rms: float: RMS average value Unit: Hz
			- Rms_Sqrt_2: float: RMS result multiplied with the square root of 2 Unit: Hz
			- Ppeak: float: Positive peak value Unit: Hz
			- Mpeak: float: Negative peak value Unit: Hz
			- Mp_Peak_Average: float: Peak-to-peak value divided by 2 Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Rms'),
			ArgStruct.scalar_float('Rms_Sqrt_2'),
			ArgStruct.scalar_float('Ppeak'),
			ArgStruct.scalar_float('Mpeak'),
			ArgStruct.scalar_float('Mp_Peak_Average')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Rms: float = None
			self.Rms_Sqrt_2: float = None
			self.Ppeak: float = None
			self.Mpeak: float = None
			self.Mp_Peak_Average: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FDEViation:MAXimum \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.demodulation.fdeviation.maximum.fetch() \n
		Queries the demodulation results for FM or FM stereo demodulation. A statistical evaluation of the frequency deviation or
		multiplex deviation is returned. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FDEViation:MAXimum?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FDEViation:MAXimum \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.demodulation.fdeviation.maximum.read() \n
		Queries the demodulation results for FM or FM stereo demodulation. A statistical evaluation of the frequency deviation or
		multiplex deviation is returned. CALCulate commands return error indicators instead of measurement values. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:DEModulation:FDEViation:MAXimum?', self.__class__.ResultData())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.InputConnector:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:CONNector \n
		Snippet: value: enums.InputConnector = driver.configure.gprfMeasurement.rfSettings.get_connector() \n
		Selects the input connector for the measured RF signal. \n
			:return: input_connector: RFCom | RFIN
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:RFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.InputConnector)

	def set_connector(self, input_connector: enums.InputConnector) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:CONNector \n
		Snippet: driver.configure.gprfMeasurement.rfSettings.set_connector(input_connector = enums.InputConnector.RFCom) \n
		Selects the input connector for the measured RF signal. \n
			:param input_connector: RFCom | RFIN
		"""
		param = Conversions.enum_scalar_to_str(input_connector, enums.InputConnector)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:RFSettings:CONNector {param}')

	def get_frequency(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:FREQuency \n
		Snippet: value: float = driver.configure.gprfMeasurement.rfSettings.get_frequency() \n
		Sets the center frequency of the RF analyzer. \n
			:return: analyzer_freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, analyzer_freq: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:FREQuency \n
		Snippet: driver.configure.gprfMeasurement.rfSettings.set_frequency(analyzer_freq = 1.0) \n
		Sets the center frequency of the RF analyzer. \n
			:param analyzer_freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(analyzer_freq)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:RFSettings:FREQuency {param}')

	def get_envelope_power(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:ENPower \n
		Snippet: value: float = driver.configure.gprfMeasurement.rfSettings.get_envelope_power() \n
		Sets the expected nominal power of the measured RF signal. The allowed range depends on several other settings, for
		example on the selected connector and the external attenuation. For supported ranges, refer to the data sheet. \n
			:return: exp_nominal_power: Unit: dBm
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:RFSettings:ENPower?')
		return Conversions.str_to_float(response)

	def set_envelope_power(self, exp_nominal_power: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:ENPower \n
		Snippet: driver.configure.gprfMeasurement.rfSettings.set_envelope_power(exp_nominal_power = 1.0) \n
		Sets the expected nominal power of the measured RF signal. The allowed range depends on several other settings, for
		example on the selected connector and the external attenuation. For supported ranges, refer to the data sheet. \n
			:param exp_nominal_power: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(exp_nominal_power)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:RFSettings:ENPower {param}')

	def get_eattenuation(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:EATTenuation \n
		Snippet: value: float = driver.configure.gprfMeasurement.rfSettings.get_eattenuation() \n
		Specifies the external attenuation in the input path. Negative values specify a gain. \n
			:return: rf_input_ext_att: Range: -50 dB to 90 dB, Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:RFSettings:EATTenuation?')
		return Conversions.str_to_float(response)

	def set_eattenuation(self, rf_input_ext_att: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:EATTenuation \n
		Snippet: driver.configure.gprfMeasurement.rfSettings.set_eattenuation(rf_input_ext_att = 1.0) \n
		Specifies the external attenuation in the input path. Negative values specify a gain. \n
			:param rf_input_ext_att: Range: -50 dB to 90 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(rf_input_ext_att)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:RFSettings:EATTenuation {param}')

	def get_rf_coupling(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:RFCoupling \n
		Snippet: value: bool = driver.configure.gprfMeasurement.rfSettings.get_rf_coupling() \n
		Couples the frequency setting of the measurement to the corresponding generator setting. \n
			:return: rf_coupling: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:RFSettings:RFCoupling?')
		return Conversions.str_to_bool(response)

	def set_rf_coupling(self, rf_coupling: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:RFSettings:RFCoupling \n
		Snippet: driver.configure.gprfMeasurement.rfSettings.set_rf_coupling(rf_coupling = False) \n
		Couples the frequency setting of the measurement to the corresponding generator setting. \n
			:param rf_coupling: OFF | ON
		"""
		param = Conversions.bool_to_str(rf_coupling)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:RFSettings:RFCoupling {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limit:
	"""Limit commands group definition. 5 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("limit", core, parent)

	@property
	def obw(self):
		"""obw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_obw'):
			from .Limit_.Obw import Obw
			self._obw = Obw(self._core, self._base)
		return self._obw

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Ch_0: bool: OFF | ON Absolute power limit checks for the designated channel '0'
			- Enable_Ch_1: bool: OFF | ON ACLR limit check for the neighbor channels '+1' and '-1'
			- Enable_Ch_2: bool: OFF | ON ACLR limit check for the neighbor channels '+2' and '-2'"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Ch_0'),
			ArgStruct.scalar_bool('Enable_Ch_1'),
			ArgStruct.scalar_bool('Enable_Ch_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Ch_0: bool = None
			self.Enable_Ch_1: bool = None
			self.Enable_Ch_2: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ENABle \n
		Snippet: value: EnableStruct = driver.configure.gprfMeasurement.acp.limit.get_enable() \n
		Enables or disables the ACLR and power limit checks. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ENABle \n
		Snippet: driver.configure.gprfMeasurement.acp.limit.set_enable(value = EnableStruct()) \n
		Enables or disables the ACLR and power limit checks. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ENABle', value)

	# noinspection PyTypeChecker
	class AclrStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Limit_Ch_1: float: Upper ACLR limit for the channels '+1' and '-1' Range: -80 dB to 10 dB, Unit: dB
			- Limit_Ch_2: float: Upper ACLR limit for the channels '+2' and '-2' Range: -80 dB to 10 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_float('Limit_Ch_1'),
			ArgStruct.scalar_float('Limit_Ch_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Limit_Ch_1: float = None
			self.Limit_Ch_2: float = None

	def get_aclr(self) -> AclrStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ACLR \n
		Snippet: value: AclrStruct = driver.configure.gprfMeasurement.acp.limit.get_aclr() \n
		Configures upper limits for the measured ACLR values. \n
			:return: structure: for return value, see the help for AclrStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ACLR?', self.__class__.AclrStruct())

	def set_aclr(self, value: AclrStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ACLR \n
		Snippet: driver.configure.gprfMeasurement.acp.limit.set_aclr(value = AclrStruct()) \n
		Configures upper limits for the measured ACLR values. \n
			:param value: see the help for AclrStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:ACLR', value)

	# noinspection PyTypeChecker
	class PowerStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Limit_Lower: float: Lower power limit Range: -130 dBm to 55 dBm, Unit: dBm
			- Limit_Upper: float: Upper power limit Range: -130 dBm to 55 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_float('Limit_Lower'),
			ArgStruct.scalar_float('Limit_Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Limit_Lower: float = None
			self.Limit_Upper: float = None

	def get_power(self) -> PowerStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:POWer \n
		Snippet: value: PowerStruct = driver.configure.gprfMeasurement.acp.limit.get_power() \n
		Configures limits for the absolute power measured in the designated channel. \n
			:return: structure: for return value, see the help for PowerStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:POWer?', self.__class__.PowerStruct())

	def set_power(self, value: PowerStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:POWer \n
		Snippet: driver.configure.gprfMeasurement.acp.limit.set_power(value = PowerStruct()) \n
		Configures limits for the absolute power measured in the designated channel. \n
			:param value: see the help for PowerStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:POWer', value)

	def clone(self) -> 'Limit':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Limit(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Net:
	"""Net commands group definition. 6 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("net", core, parent)

	@property
	def subnet(self):
		"""subnet commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subnet'):
			from .Net_.Subnet import Subnet
			self._subnet = Subnet(self._core, self._base)
		return self._subnet

	def get_adapter(self) -> str:
		"""SCPI: SYSTem:COMMunicate:NET:ADAPter \n
		Snippet: value: str = driver.system.communicate.net.get_adapter() \n
		Selects the network adapter and thus the connection type to be modified. All SYSTem:COMMunicate:NET... commands affect
		the selected network adapter. This command does not activate or deactivate a network adapter. \n
			:return: network_adapter: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NET:ADAPter?')
		return trim_str_response(response)

	def set_adapter(self, network_adapter: str) -> None:
		"""SCPI: SYSTem:COMMunicate:NET:ADAPter \n
		Snippet: driver.system.communicate.net.set_adapter(network_adapter = '1') \n
		Selects the network adapter and thus the connection type to be modified. All SYSTem:COMMunicate:NET... commands affect
		the selected network adapter. This command does not activate or deactivate a network adapter. \n
			:param network_adapter: String parameter
		"""
		param = Conversions.value_to_quoted_str(network_adapter)
		self._core.io.write(f'SYSTem:COMMunicate:NET:ADAPter {param}')

	def get_gateway(self) -> str:
		"""SCPI: SYSTem:COMMunicate:NET:GATeway \n
		Snippet: value: str = driver.system.communicate.net.get_gateway() \n
		Defines IPv4 addresses of default gateways. The configuration is only possible if DHCP is disabled. A query returns the
		currently defined addresses, irrespective of whether they have been specified manually or via DHCP. \n
			:return: gateway: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NET:GATeway?')
		return trim_str_response(response)

	def set_gateway(self, gateway: str) -> None:
		"""SCPI: SYSTem:COMMunicate:NET:GATeway \n
		Snippet: driver.system.communicate.net.set_gateway(gateway = '1') \n
		Defines IPv4 addresses of default gateways. The configuration is only possible if DHCP is disabled. A query returns the
		currently defined addresses, irrespective of whether they have been specified manually or via DHCP. \n
			:param gateway: String parameter, gateway IP address consisting of four blocks separated by dots Several strings separated by commas can be entered, or several addresses separated by commas can be included in one string.
		"""
		param = Conversions.value_to_quoted_str(gateway)
		self._core.io.write(f'SYSTem:COMMunicate:NET:GATeway {param}')

	def get_ip_address(self) -> List[str]:
		"""SCPI: SYSTem:COMMunicate:NET:IPADdress \n
		Snippet: value: List[str] = driver.system.communicate.net.get_ip_address() \n
		Assigns one or more IPv4 addresses to the network adapter. The configuration is only possible if DHCP is disabled.
		A query returns the currently assigned addresses, irrespective of whether they have been assigned manually or via DHCP. \n
			:return: ip_address: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NET:IPADdress?')
		return Conversions.str_to_str_list(response)

	def set_ip_address(self, ip_address: List[str]) -> None:
		"""SCPI: SYSTem:COMMunicate:NET:IPADdress \n
		Snippet: driver.system.communicate.net.set_ip_address(ip_address = ['1', '2', '3']) \n
		Assigns one or more IPv4 addresses to the network adapter. The configuration is only possible if DHCP is disabled.
		A query returns the currently assigned addresses, irrespective of whether they have been assigned manually or via DHCP. \n
			:param ip_address: String parameter, IP address consisting of four blocks (octets) separated by dots Several strings separated by commas can be entered, or several addresses separated by commas can be included in one string.
		"""
		param = Conversions.list_to_csv_quoted_str(ip_address)
		self._core.io.write(f'SYSTem:COMMunicate:NET:IPADdress {param}')

	def get_hostname(self) -> str:
		"""SCPI: SYSTem:COMMunicate:NET:HOSTname \n
		Snippet: value: str = driver.system.communicate.net.get_hostname() \n
		Sets the host name of the R&S CMA180. \n
			:return: hostname: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NET:HOSTname?')
		return trim_str_response(response)

	def set_hostname(self, hostname: str) -> None:
		"""SCPI: SYSTem:COMMunicate:NET:HOSTname \n
		Snippet: driver.system.communicate.net.set_hostname(hostname = '1') \n
		Sets the host name of the R&S CMA180. \n
			:param hostname: Host name as string
		"""
		param = Conversions.value_to_quoted_str(hostname)
		self._core.io.write(f'SYSTem:COMMunicate:NET:HOSTname {param}')

	def get_dhcp(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:NET:DHCP \n
		Snippet: value: bool = driver.system.communicate.net.get_dhcp() \n
		Enables or disables DHCP. \n
			:return: dhcp_enable: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NET:DHCP?')
		return Conversions.str_to_bool(response)

	def set_dhcp(self, dhcp_enable: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:NET:DHCP \n
		Snippet: driver.system.communicate.net.set_dhcp(dhcp_enable = False) \n
		Enables or disables DHCP. \n
			:param dhcp_enable: 1 | 0 1: DHCP enabled and automatic TCP/IP address configuration 0: DHCP disabled and manual address configuration
		"""
		param = Conversions.bool_to_str(dhcp_enable)
		self._core.io.write(f'SYSTem:COMMunicate:NET:DHCP {param}')

	def clone(self) -> 'Net':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Net(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
